@@ -34,47 +34,45 @@ def request_accesstoken(acc: str, pwd: str) -> str:
 
 class base:
     def __init__(self, token, app_secret=None):
+        """[summary]
+
+        Args:
+            token ([type]): [description]
+            app_secret ([type], optional): [description]. Defaults to None.
+        """
         self.token = token
         self.app_secret = app_secret
 
-    def request(self, api_name=None, params={}, data={}, method="GET",
-                url=None, json={}, headers={}, api_prefix="api/"):
+    def request(self, api_name=None, method="GET",
+                url=None, api_prefix="api/", **kwargs):
         host_name = "http://bms.microc.cn/shopguide/"
         # host_name = "http://test.xxynet.com/shopguide/api/"
         if not url:
-            if host_name not in api_name:
-                url = f"{host_name}{api_prefix}{api_name}"
-        if "accessToken" not in params:
-            # 没有token自动添加
-            params["accessToken"] = self.token
-        if "appSecret" not in params:
-            # 没有token自动添加
-            params["appSecret"] = self.app_secret
+            # url is None:generate url use hostname+api_prefix+apiname
+            url = f"{host_name}{api_prefix}{api_name}"
+        # params
+        params = kwargs.get("params", {})
+        params["accessToken"] = self.token
+        params["appSecret"] = self.app_secret
+        kwargs["params"] = params
+        # cookies
+        cookies = kwargs.get("cookies", {})
+        cookies["accessToken"] = self.token
+        kwargs["cookies"] = cookies
+        # other
+        # kwargs["headers"] = kwargs.get("headers", {})
+        # kwargs["json"] = kwargs.get("json", {})
+        # kwargs["data"] = kwargs.get("data", {})
 
-        if method == "GET":
-            params.update(data)
-            response = requests.get(url, params=params, headers=headers)
-        elif method == "POST":
-            if data:
-                response = requests.post(
-                    url, params=params, data=data, headers=headers)
-            elif json:
-                response = requests.post(
-                    url, params=params, json=json, headers=headers)
-            else:
-                logger.warning({
-                    "msg": "网络请求数据格式错误。",
-                    "method": "POST",
-                    "data": "没有任何数据请求，为什么不用GET？",
-                })
-                response = requests.post(url, params=params, headers=headers)
-
-        else:
-            raise ValueError("请求方法错误。")
+        response = requests.request(
+            method=method,
+            url=url,
+            **kwargs
+        )
         if response.status_code == 200:
             # logger.debug({
             #     "url": url,
-            #     "headers": headers,
+            #     "self.token": self.token,
             #     "response": response.text,
             # })
             return self.response(response.json())
